@@ -3,7 +3,7 @@
 """
 Selector classes.
 
-Copyright (C) 2005, 2006 Paul Boddie <paul@boddie.org.uk>
+Copyright (C) 2005, 2006, 2007 Paul Boddie <paul@boddie.org.uk>
 
 This software is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -244,9 +244,8 @@ class ItemSelectorResource:
 
     path_encoding = "utf-8"
 
-    def __init__(self, editor, viewer, importer, exporter, prop_viewer):
+    def __init__(self, editor, importer, exporter, prop_viewer):
         self.editor = editor
-        self.viewer = viewer
         self.importer = importer
         self.exporter = exporter
         self.prop_viewer = prop_viewer
@@ -293,17 +292,13 @@ class ItemSelectorResource:
             if trans.get_request_method() == "GET":
 
                 # Serve the underlying resource.
+                # NOTE: Perhaps perform a check for a suffixed name here instead.
+                # NOTE: This would also mean that the property listing would need
+                # NOTE: to show other resources.
 
                 if len(vpath_fields) == 1:
                     self.exporter.respond(trans)
                     raise EndOfResponse
-
-                # Or serve the view of the resource.
-
-                elif attributes.has_key("filter-type") and not attributes.has_key("item-value"):
-                    self.viewer.respond(trans)
-                    raise EndOfResponse
-
                 else:
                     self.editor.respond(trans)
                     raise EndOfResponse
@@ -320,12 +315,8 @@ class ItemSelectorResource:
 
                 # Detect filter view actions.
 
-                if attributes.has_key("filter-type") and not attributes.has_key("item-value"):
-                    self.viewer.respond(trans)
-                    raise EndOfResponse
-                else:
-                    self.editor.respond(trans)
-                    raise EndOfResponse
+                self.editor.respond(trans)
+                raise EndOfResponse
 
             # For PROPFIND methods, provide a special property listing.
 
@@ -342,7 +333,8 @@ class ItemSelectorResource:
 
         # Provide other responses if other parts of the path are found.
 
-        self.viewer.respond(trans)
+        trans.set_response_code(404)
+        trans.get_response_stream().write("Resource not found")
         raise EndOfResponse
 
 class TypeSelectorResource:
@@ -475,4 +467,38 @@ class ExporterSelectorResource:
             trans.get_response_stream().write("Method not allowed")
             raise EndOfResponse
 
+class DepthFilterResource:
+
+    "A resource preventing depth infinity requests."
+
+    def __init__(self, resource):
+        self.resource = resource
+
+    def respond(self, trans):
+
+        "Refuse depth of infinity in the given transaction 'trans'."
+
+        # NOTE: Controversial!
+
+        if "infinity" in trans.get_header_values("Depth"):
+            trans.set_response_code(400)
+            trans.get_response_stream().write("Depth cannot be infinity")
+            raise EndOfResponse
+
+        self.resource.respond(trans)
+
+class OptionsSelectorResource:
+
+    "A resource providing options responses."
+
+    def __init__(self, resource):
+        self.resource = resource
+
+    def respond(self, trans):
+        if trans.get_request_method() == "OPTIONS":
+            trans.set_header_value("DAV", "1")
+            raise EndOfResponse
+
+        self.resource.respond(trans)
+
 # vim: tabstop=4 expandtab shiftwidth=4
