@@ -3,7 +3,7 @@
 """
 Viewer classes.
 
-Copyright (C) 2005, 2006 Paul Boddie <paul@boddie.org.uk>
+Copyright (C) 2005, 2006, 2007 Paul Boddie <paul@boddie.org.uk>
 
 This software is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -389,6 +389,11 @@ class PropertyViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
             else:
                 items_root.setAttribute("items-are-containers", "no")
 
+            # Fix the path information, if necessary.
+
+            if not encoded_ppath.endswith("/"):
+                encoded_ppath += "/"
+
             # Support collections represented by file-like resources.
 
             if attributes.has_key("collection-export"):
@@ -396,11 +401,6 @@ class PropertyViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
                 items_root.setAttribute("collection-export", "yes")
                 found_items = []
             else:
-                # Fix the path information, if necessary.
-
-                if not encoded_pvpath.endswith("/"):
-                    encoded_pvpath += "/"
-
                 found_items = self.store.get_items_using_attributes(attributes)
                 set_filter_attributes(items_root, attributes)
 
