@@ -2,7 +2,10 @@
 
 from WebStack.Adapters.BaseHTTPRequestHandler import deploy
 import WebCalendar
-import WebCalendar.RDFAccess
+import WebOrganiser.RDFAccess
+import RDFFormats.Store
+import RDFCalendar.Store
+import RDFMessage.Store
 import cmdsyntax
 
 def main(argv):
@@ -10,17 +13,20 @@ def main(argv):
     # Get the store.
 
     syntax = cmdsyntax.Syntax("""
-        NAME TYPE [--module=MODULE_NAME] [--base=BASE_URI] [--host=HOST] [--port=PORT] [--debug]
+        --store=NAME [--store-type=TYPE] [--module=MODULE_NAME] [--base=BASE_URI] [--host=HOST] [--port=PORT] [--debug]
         """)
 
     syntax_matches = syntax.get_args(argv[1:])
 
     try:
         args = syntax_matches[0]
-        store = WebCalendar.RDFAccess.open(args["NAME"], args["TYPE"], base_uri=args.get("base"), database_module_name=args.get("module"),
+        _store, _impl = RDFFormats.Store.open(args["store"], args.get("store-type", "sqltriples"), database_module_name=args.get("module"),
             debug=args.has_key("debug"))
+        cstore = RDFCalendar.Store.Store(_store, _impl)
+        mstore = RDFMessage.Store.Store(_store, _impl)
+        store = WebOrganiser.RDFAccess.open(_store, [cstore, mstore], base_uri=args.get("base"))
     except IndexError:
-        print "Need a store name and a store type (rdflib or sqltriples)."
+        print "Need a store name. The store type is sqltriples by default."
         print "For sqltriples, the database module name must also be given (PgSQL or pysqlite2)."
         print "An optional base URI can also be specified for permanent resource references."
         print "To change the server's address details, specify the optional host and port."
