@@ -31,9 +31,10 @@ icon_sets = {
         ("actions", "kontact_contacts", "card"),
         ("actions", "viewmag", "search"),
         ("actions", "kontact_journal", "journal"),
-        ("actions", "kontact_mail", "message"),
+        ("actions", "mail_generic", "e-mail"),
         ("actions", "kontact_todo", "to-do"),
         ("actions", "kontact_date", "event"),
+        ("mimetypes", "vcalendar", "calendar"),
         ("actions", "down", "sort-ascending"),
         ("actions", "up", "sort-descending"),
         ("actions", "filenew", "created"),
@@ -46,10 +47,11 @@ icon_sets = {
         #("actions", "edit", None),
         ("actions", "viewmag", "search"),
         ("actions", "easymoblog", "journal"),
-        ("apps", "email", "message"),
+        ("actions", "mail_generic", "e-mail"),
         #("apps", "reminders", "to-do"),
         ("apps", "korganizer", "to-do"),
         ("apps", "cal", "event"),
+        ("mimetypes", "vcalendar", "calendar"),
         ("actions", "down", "sort-ascending"),
         ("actions", "up", "sort-descending"),
         ("mimetypes", "empty", "created"),
@@ -62,9 +64,10 @@ icon_sets = {
         ("mimetypes", "x-office-address-book", "card"),
         ("actions", "system-search", "search"),
         ("apps", "accessories-text-editor", "journal"),
-        ("apps", "internet-mail", "message"),
+        ("apps", "internet-mail", "e-mail"),
         ("apps", "accessories-text-editor", "to-do"),
         ("mimetypes", "x-office-calendar", "event"),
+        ("apps", "office-calendar", "calendar"),
         ("actions", "go-down", "sort-ascending"),
         ("actions", "go-up", "sort-descending"),
         ("actions", "document-new", "created"),
